preParser.UrlPreParser

|  | ## Cheshire3 Object Model: Class UrlPreParser

Module preParser :: Class UrlPreParser

## Class UrlPreParser
source code

Object Tree:

               object --+
                        |
    configParser.C3Object --+
                            |
        baseObjects.PreParser --+
                                |
                               UrlPreParser

Known Subclasses:
  OpenOfficePreParser

Instance Methods

post_multipart(self, host, selector, fields, files)
encode_multipart_formdata(self, fields, files)
get_content_type(self, filename)
send_request(self, session, data=None)
Inherited from `baseObjects.PreParser`: `process_document` Inherited from `configParser.C3Object`: `__init__`, `auth_function`, `get_config`, `get_default`, `get_object`, `get_path`, `get_setting`, `log_function`, `unauth_function`, `unlog_function` Inherited from `configParser.C3Object` (private): `_getDomFromFile`, `_handleConfigNode`, `_parseIncludes`, `_recurseSubConfigs`, `_verifyDefault`, `_verifyOption`, `_verifySetting` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables

Inherited from `configParser.C3Object`: `configStore`, `defaults`, `functionLogger`, `id`, `name`, `objectType`, `objects`, `parent`, `paths`, `permissionHandlers`, `settings`, `subConfigs`, `unresolvedObjects` Inherited from `configParser.C3Object` (private): `_includeConfigStores`, `_objectRefs` Inherited from `object`: `__class__`

Method Details

### post_multipart(self, host, selector, fields, files) | source code

### encode_multipart_formdata(self, fields, files) | source code

### get_content_type(self, filename) | source code

### send_request(self, session, data=None) | source code